Crate nice_plug_egui

Crate nice_plug_egui 

egui editor support for nice-plug.

TODO: Proper usage example, for now check out the gain_gui example

Modules

baseview
Re-export for convenience.
resizable_window
Resizable window wrapper for Egui editor.
widgets
Custom egui widgets for displaying parameter values.

Structs

EguiSettings
EguiState
State for an nice-plug-egui editor.
EguiWindow
Re-export for convenience. Handles an egui-baseview application
GlConfig
GraphicsConfig
Re-export for convenience.
Queue
Re-export for convenience.

Enums

Key
Re-export for convenience. Key represents the meaning of a keypress.
KeyCapture
Re-export for convenience. Describes how to handle capturing key events from the host.
Profile

Functions

create_egui_editor
Create an Editor instance using an egui GUI. Using the user state parameter is optional, but it can be useful for keeping track of some temporary GUI-only settings. See the nice-plug_gain_egui example for more information on how to use this. The EguiState passed to this function contains the GUI’s intitial size, and this is kept in sync whenever the GUI gets resized. You can also use this to know if the GUI is open, so you can avoid performing potentially expensive calculations while the GUI is not open. If you want this size to be persisted when restoring a plugin instance, then you can store it in a #[persist = "key"] field on your parameters struct.