pub struct WindowOpenOptions {
pub title: String,
pub size: Size,
pub scale: WindowScalePolicy,
pub gl_config: Option<GlConfig>,
}Expand description
The options for opening a new window
Fields
title: Stringsize: SizeThe logical size of the window
These dimensions will be scaled by the scaling policy specified in scale. Mouse
position will be passed back as logical coordinates.
scale: WindowScalePolicyThe dpi scaling policy
gl_config: Option<GlConfig>If provided, then an OpenGL context will be created for this window. You’ll be able to access this context through crate::Window::gl_context.
By default this is set to None.