pub enum KeyCapture {
CaptureAll,
IgnoreAll,
CaptureKeys(Vec<Key>),
IgnoreKeys(Vec<Key>),
}Expand description
Re-export for convenience. Describes how to handle capturing key events from the host.
Variants
CaptureAll
All keys will be captured from the host.
IgnoreAll
No keys will be captured from the host.
CaptureKeys(Vec<Key>)
Only the given keys will be captured from the host.
IgnoreKeys(Vec<Key>)
All keys except the given ones will be captured from the host.