pub struct EguiWindow<State, U>{ /* private fields */ }Expand description
Re-export for convenience. Handles an egui-baseview application
Implementations
Sourceimpl<State, U> EguiWindow<State, U>
impl<State, U> EguiWindow<State, U>
Sourcepub fn open_parented<P, B>(
parent: &P,
settings: WindowOpenOptions,
graphics_config: GraphicsConfig,
state: State,
build: B,
update: U,
) -> WindowHandle
pub fn open_parented<P, B>( parent: &P, settings: WindowOpenOptions, graphics_config: GraphicsConfig, state: State, build: B, update: U, ) -> WindowHandle
Open a new child window.
parent- The parent window.settings- The settings of the window.state- The initial state of your application.build- Called once before the first frame. Allows you to do setup code and to callctx.set_fonts(). Optional.update- Called before each frame. Here you should update the state of your application and build the UI.
Sourcepub fn open_blocking<B>(
settings: WindowOpenOptions,
graphics_config: GraphicsConfig,
state: State,
build: B,
update: U,
)
pub fn open_blocking<B>( settings: WindowOpenOptions, graphics_config: GraphicsConfig, state: State, build: B, update: U, )
Open a new window that blocks the current thread until the window is destroyed.
settings- The settings of the window.state- The initial state of your application.build- Called once before the first frame. Allows you to do setup code and to callctx.set_fonts(). Optional.update- Called before each frame. Here you should update the state of your application and build the UI.