GraphicsConfig

Struct GraphicsConfig 

pub struct GraphicsConfig {
    pub dithering: bool,
    pub shader_version: Option<ShaderVersion>,
}
Re-export for convenience.

Fields

dithering: bool

Controls whether to apply dithering to minimize banding artifacts.

Dithering assumes an sRGB output and thus will apply noise to any input value that lies between two 8bit values after applying the sRGB OETF function, i.e. if it’s not a whole 8bit value in “gamma space”. This means that only inputs from texture interpolation and vertex colors should be affected in practice.

Defaults to true.

shader_version: Option<ShaderVersion>

Needed for cross compiling for VirtualBox VMSVGA driver with OpenGL ES 2.0 and OpenGL 2.1 which doesn’t support SRGB texture. See https://github.com/emilk/egui/pull/1993.

For OpenGL ES 2.0: set this to egui_glow::ShaderVersion::Es100 to solve blank texture problem (by using the “fallback shader”).