Module widgets

Module widgets 

Custom egui widgets for displaying parameter values.

Note

None of these widgets are finalized, and their sizes or looks can change at any point. Feel free to copy the widgets and modify them to your personal taste.

Modules

generic_ui
A simple generic UI widget that renders all parameters in a Params object as a scrollable list of sliders and labels.
util
Utilities for creating these widgets.

Structs

ParamSlider
A slider widget similar to egui::widgets::Slider that knows about nice-plug parameters ranges and can get values for it. The slider supports double click and control click to reset, shift+drag for granular dragging, text value entry by clicking on the value text.