EguiState

Struct EguiState 

pub struct EguiState { /* private fields */ }
State for an nice-plug-egui editor.

Implementations

Source

impl EguiState

pub fn from_size(width: u32, height: u32) -> Arc<EguiState>

Initialize the GUI’s state. This value can be passed to create_egui_editor(). The window size is in logical pixels, so before it is multiplied by the DPI scaling factor.

pub fn size(&self) -> (u32, u32)

Returns a (width, height) pair for the current size of the GUI in logical pixels.

pub fn is_open(&self) -> bool

Whether the GUI is currently visible.

pub fn set_requested_size(&self, new_size: (u32, u32))

Set the new size (in logical pixels) that will be used to resize the window if the host allows.