EguiWindow

Struct EguiWindow 

pub struct EguiWindow<State, U>
where State: 'static + Send, U: FnMut(&mut Ui, &mut Queue<'_>, &mut State) + 'static + Send,
{ /* private fields */ }
Re-export for convenience. Handles an egui-baseview application

Implementations

Source

impl<State, U> EguiWindow<State, U>
where State: 'static + Send, U: FnMut(&mut Ui, &mut Queue<'_>, &mut State) + 'static + Send,

pub fn open_parented<P, B>( parent: &P, settings: WindowOpenOptions, graphics_config: GraphicsConfig, state: State, build: B, update: U, ) -> WindowHandle
where P: HasRawWindowHandle, B: FnMut(&Context, &mut Queue<'_>, &mut State) + 'static + Send,

Open a new child window.

  • parent - The parent window.
  • settings - The settings of the window.
  • state - The initial state of your application.
  • build - Called once before the first frame. Allows you to do setup code and to call ctx.set_fonts(). Optional.
  • update - Called before each frame. Here you should update the state of your application and build the UI.
pub fn open_blocking<B>( settings: WindowOpenOptions, graphics_config: GraphicsConfig, state: State, build: B, update: U, )
where B: FnMut(&Context, &mut Queue<'_>, &mut State) + 'static + Send,

Open a new window that blocks the current thread until the window is destroyed.

  • settings - The settings of the window.
  • state - The initial state of your application.
  • build - Called once before the first frame. Allows you to do setup code and to call ctx.set_fonts(). Optional.
  • update - Called before each frame. Here you should update the state of your application and build the UI.